@@ -355,6 +355,7 @@ fi
 # -------------------------------------------------------------------------------------
 # Patch JBR to make self-contained JVM (requires nothing from host system except glibc)
 # -------------------------------------------------------------------------------------
+
 if [ -n "${REMOTE_DEV_SERVER_USE_SELF_CONTAINED_LIBS:-}" ]; then
   # already set by environment
   echo "\$REMOTE_DEV_SERVER_USE_SELF_CONTAINED_LIBS=$REMOTE_DEV_SERVER_USE_SELF_CONTAINED_LIBS"
@@ -366,6 +367,12 @@ elif /lib64/ld-linux-x86-64.so.2 2>&1 | grep -q "gcompat ELF interpreter stub";
 elif /lib/ld-linux-aarch64.so.1 2>&1 | grep -q "gcompat ELF interpreter stub"; then
   # Not usable under Alpine and other musl-based linux distributions (aarch64)
   REMOTE_DEV_SERVER_USE_SELF_CONTAINED_LIBS=0
+elif /lib/ld-musl-x86_64.so.1 2>&1 | grep -q "musl libc"; then
+  # Not usable under Alpine and other musl-based linux distributions (x86-64)
+  REMOTE_DEV_SERVER_USE_SELF_CONTAINED_LIBS=0
+elif /lib/ld-musl-aarch64.so.1 2>&1 | grep -q "musl libc"; then
+  # Not usable under Alpine and other musl-based linux distributions (aarch64)
+  REMOTE_DEV_SERVER_USE_SELF_CONTAINED_LIBS=0
 else
   REMOTE_DEV_SERVER_USE_SELF_CONTAINED_LIBS=1
 fi
@@ -424,9 +431,7 @@ fi
 
 TEMP_REMOTE_DEV_PROPERTIES_PATH="$TEMP_SYSTEM_LIKE_DIR/pid.$$.temp.remote-dev.properties"
 
-# shellcheck disable=SC2016
-#TODO: use IDE-specific properties file
-cat "$IDE_BIN_DIR/idea.properties" > "$TEMP_REMOTE_DEV_PROPERTIES_PATH"
+printf '' > "$TEMP_REMOTE_DEV_PROPERTIES_PATH"
 
 if [ $PER_PROJECT_CONFIGS -eq 1 ]; then
   #TODO: use IDE-specific folder
@@ -441,9 +446,6 @@ fi
 #TODO: remove once all of this is disabled for remote dev
 # shellcheck disable=SC2129
 # stylistic issue
-printf '\njb.privacy.policy.text="<!--999.999-->"' >> "$TEMP_REMOTE_DEV_PROPERTIES_PATH"
-printf '\njb.consents.confirmation.enabled=false' >> "$TEMP_REMOTE_DEV_PROPERTIES_PATH"
-printf '\nidea.initially.ask.config=never' >> "$TEMP_REMOTE_DEV_PROPERTIES_PATH"
 printf '\nide.show.tips.on.startup.default.value=false' >> "$TEMP_REMOTE_DEV_PROPERTIES_PATH"
 printf '\nshared.indexes.download=true' >> "$TEMP_REMOTE_DEV_PROPERTIES_PATH"
 printf '\nshared.indexes.download.auto.consent=true' >> "$TEMP_REMOTE_DEV_PROPERTIES_PATH"
@@ -538,12 +540,6 @@ fi
 
 export "${IDE_PRODUCT_UC}_PROPERTIES=$TEMP_REMOTE_DEV_PROPERTIES_PATH"
 
-# GTW-6786 fix macos host crashing on start
-if [ $IS_DARWIN -eq 1 ]; then
-  export INTELLIJ_ORIGINAL_ENV_AWT_FORCE_HEADFUL="${AWT_FORCE_HEADFUL:-}"
-  export AWT_FORCE_HEADFUL=true
-fi
-
 # ---------------------------------------------------------------------
 # Run the IDE.
 # ---------------------------------------------------------------------
